#
# spec file for package sigil
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sigil
Version:        0.9.8
Release:        0
Summary:        WYSIWYG Ebook Editor
License:        GPL-3.0
Group:          Productivity/Other
Url:            http://sigil-ebook.com/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        https://github.com/Sigil-Ebook/Sigil/archive/%{version}.tar.gz
Source1:        https://github.com/Sigil-Ebook/Sigil/raw/master/docs/Sigil_User_Guide_0_7_2.epub
Source2:        %{name}.desktop
# PATCH-FIX-OPENSUSE Disabled __DATE__ and __TIME__ which is replaced later in pre section
Patch0:         %{name}-gt-0.9.0-Dialogs-About.cpp.patch
# PATCH-FIX-OPENSUSE Set right version
Patch1:         %{name}-version.patch

BuildRequires:  cmake >= 3.0
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hunspell-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebChannel)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  libqt5-qtbase-devel >= 5.4.2
BuildRequires:  libqt5-qtlocation-devel >= 5.4.2
BuildRequires:  libstdc++-devel
BuildRequires:  libxerces-c-devel
BuildRequires:  make
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pcre-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  python3-devel >= 3.4
BuildRequires:  dos2unix
# not need for build, only check for exists
BuildRequires:  python3-tk
BuildRequires:  python3-six
BuildRequires:  python3-lxml
BuildRequires:  python3-html5lib
#BuildRequires:  python3-regex
BuildRequires:  python3-Pillow
BuildRequires:  python3-cssutils
BuildRequires:  python3-cssselect
#BuildRequires:  python3-chardet
Requires:       python3-tk
Requires:       python3-six
Requires:       python3-lxml
Requires:       python3-html5lib
#Requires:       python3-regex
Requires:       python3-Pillow
Requires:       python3-cssutils
Requires:       python3-cssselect
#Requires:       python3-chardet



%description
Sigil is an editor for the EPUB format. It is designed for WYSIWYG
editing of EPUB files and for converting other formats to EPUB. It
also provides support for direct XHTML, CSS and XPGT editing. You can
use it to add any of the metadata entries supported by the EPUB
specification and create a hierarchical Table of Contents.

%prep
%setup -q -n Sigil-%{version}
sed -i 's/\r//' ChangeLog.txt README.md COPYING.txt
%patch0 -p 1
%patch1 -p 1
%{__cp} -v %{S:1} .
%{__cp} -v %{S:2} .
# rpmlint
dos2unix src/Resource_Files/python3lib/meta*.py
dos2unix src/Resource_Files/python3lib/opf_*.py



#FIXME MANUAL UPDATE OF DATE REQUIRED HERE!!!!
# Fix "Your file uses  __DATE and __TIME__ this causes the package to rebuild 
# when not needed warning"
# http://sourceforge.net/tracker/?func=detail&atid=102439&aid=3314371&group_id=2439
#
# We use the current date
_date=$(date +"%Y%m%d")
_time=$(date +"%H:%M:%S")
# Change it:
find . -type f -name 'About.cpp' | xargs sed -i "s/@DATE@/$_date/;s/@TIME@/$_time/g" 

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"

cmake -G "Unix Makefiles" \
   -DCMAKE_INSTALL_PREFIX=%_prefix \
   -DCMAKE_BUILD_TYPE=Release .

make %{?_smp_mflags}

%install
%make_install

# create a .desktop file:
mkdir -p %{buildroot}%{_datadir}/applications

# install icons for the .desktop file
install -m644 -D src/Resource_Files/icon/app_icon_16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/sigil.png
install -m644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %name
%fdupes -s %buildroot

%files
%defattr(-,root,root)
%doc ChangeLog.txt README.md COPYING.txt Sigil_User_Guide_0_7_2.epub
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/16x16
%dir %{_datadir}/icons/hicolor/16x16/apps
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/pixmaps/*.png
%dir %{_datadir}/%name
%dir %{_datadir}/%name/translations
%{_datadir}/%{name}/translations/*
%dir %{_datadir}/%name/*dictionaries
%{_datadir}/%{name}/*dictionaries/*
%{_datadir}/%{name}/examples
%{_datadir}/%{name}/python3lib
%dir %{_datadir}/%{name}/polyfills
%{_datadir}/%{name}/polyfills/MathJax.js
%{_datadir}/%{name}/plugin_launchers
%dir /usr/lib/%name
/usr/lib/%{name}/*

%changelog
